@@ -1,18 +1,14 @@
-ALMS_USER = {
+import os
 
-}
+LIBRARY_ROOT = os.path.dirname(os.path.abspath(__file__))
 
-LABS_USER = {
-
-}
+ALMS_USER = None
+LABS_USER = None
 
 ALMS_IDENTITY_SERVER = None
 ALMS_USERS_API = None
-
 LABS_API = None
 
 PROJECT = None
-PROJECT_ROOT = None
-
 CERT_PATH = None
 WAIT_TIMEOUT = None
